@@ -18,12 +18,9 @@ class RawDataVersionAdmin(BaseAdmin):
         "release_datetime",
         "pretty_download_size",
         "download_file_count",
-        "download_record_count",
         "clean_file_count",
         "clean_record_count",
         "pretty_clean_size",
-        "download_file_count",
-        "clean_record_count"
     )
     list_display_links = ('release_datetime',)
     list_filter = ("release_datetime",)
@@ -38,10 +35,8 @@ class RawDataFileAdmin(BaseAdmin):
         "id",
         "version",
         "file_name",
-        "download_records_count",
         "clean_records_count",
         "load_records_count",
-        "error_count"
     )
     list_display_links = ('id', 'file_name',)
     list_filter = ("version__release_datetime",)
