@@ -1,9 +1,108 @@
-__all__ = [
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+"""
+Import all of the models from submodules and thread them together.
+"""
+from calaccess_raw.models.base import CalAccessBaseModel
+from calaccess_raw.models.campaign import (
+    CvrSoCd,
+    Cvr2SoCd,
+    CvrCampaignDisclosureCd,
+    Cvr2CampaignDisclosureCd,
+    Cvr3VerificationInfoCd,
+    DebtCd,
+    ExpnCd,
+    LoanCd,
+    RcptCd,
+    S401Cd,
+    F495P2Cd,
+    S496Cd,
+    S497Cd,
+    S498Cd,
+    F501502Cd
+)
+from calaccess_raw.models.inactive import (
+    BallotMeasuresCd,
+    CvrF470Cd,
+    FilerTypePeriodsCd,
+    LobbyistContributions1Cd,
+    LobbyistContributions2Cd,
+    LobbyistContributions3Cd,
+    LobbyistEmpLobbyist1Cd,
+    LobbyistEmpLobbyist2Cd,
+    LobbyistEmployer1Cd,
+    LobbyistEmployer2Cd,
+    LobbyistEmployer3Cd,
+    LobbyistEmployerFirms1Cd,
+    LobbyistEmployerFirms2Cd,
+    LobbyistEmployerHistoryCd,
+    LobbyistFirm1Cd,
+    LobbyistFirm2Cd,
+    LobbyistFirm3Cd,
+    LobbyistFirmEmployer1Cd,
+    LobbyistFirmEmployer2Cd,
+    LobbyistFirmHistoryCd,
+    LobbyistFirmLobbyist1Cd,
+    LobbyistFirmLobbyist2Cd,
+    EfsFilingLogCd
+)
+from calaccess_raw.models.lobbying import (
+    CvrRegistrationCd,
+    Cvr2RegistrationCd,
+    LobbyAmendmentsCd,
+    LobbyingChgLogCd,
+    LempCd,
+    CvrLobbyDisclosureCd,
+    Cvr2LobbyDisclosureCd,
+    F690P2Cd,
+    LattCd,
+    LexpCd,
+    LccmCd,
+    LpayCd,
+    LothCd
+)
+from calaccess_raw.models.common import (
+    CvrE530Cd,
+    FilernameCd,
+    FilerFilingsCd,
+    FilingsCd,
+    HdrCd,
+    HeaderCd,
+    SmryCd,
+    SpltCd,
+    TextMemoCd,
+    AcronymsCd,
+    AddressCd,
+    FilersCd,
+    FilerAcronymsCd,
+    FilerAddressCd,
+    FilerEthicsClassCd,
+    FilerInterestsCd,
+    FilerLinksCd,
+    FilerStatusTypesCd,
+    FilerToFilerTypeCd,
+    FilerTypesCd,
+    FilerXrefCd,
+    FilingPeriodCd,
+    GroupTypesCd,
+    ImageLinksCd,
+    LegislativeSessionsCd,
+    LookupCodesCd,
+    NamesCd,
+    ReceivedFilingsCd,
+    ReportsCd
+)
+from calaccess_raw.models.tracking import (
+    RawDataVersion,
+    RawDataFile
+)
+__all__ = (
     'CalAccessBaseModel',
     'CvrSoCd',
     'Cvr2SoCd',
     'CvrCampaignDisclosureCd',
     'Cvr2CampaignDisclosureCd',
+    'CvrF470Cd',
     'RcptCd',
     'Cvr3VerificationInfoCd',
     'LoanCd',
@@ -49,6 +148,7 @@ __all__ = [
     'FilerTypesCd',
     'FilerXrefCd',
     'FilingPeriodCd',
+    'FilerTypePeriodsCd',
     'GroupTypesCd',
     'HeaderCd',
     'HdrCd',
@@ -61,6 +161,7 @@ __all__ = [
     'LobbyistEmployer1Cd',
     'LobbyistEmployer2Cd',
     'LobbyistEmployer3Cd',
+    'LobbyistEmployerHistoryCd',
     'LobbyistEmployerFirms1Cd',
     'LobbyistEmployerFirms2Cd',
     'LobbyistEmpLobbyist1Cd',
@@ -72,94 +173,11 @@ __all__ = [
     'LobbyistFirmEmployer2Cd',
     'LobbyistFirmLobbyist1Cd',
     'LobbyistFirmLobbyist2Cd',
-    'LookupCode',
+    'LobbyistFirmHistoryCd',
+    'LookupCodesCd',
     'NamesCd',
     'ReceivedFilingsCd',
     'ReportsCd',
-]
-
-from base import CalAccessBaseModel
-from campaign import (
-    CvrSoCd,
-    Cvr2SoCd,
-    CvrCampaignDisclosureCd,
-    Cvr2CampaignDisclosureCd,
-    RcptCd,
-    Cvr3VerificationInfoCd,
-    LoanCd,
-    S401Cd,
-    ExpnCd,
-    F495P2Cd,
-    DebtCd,
-    S496Cd,
-    SpltCd,
-    S497Cd,
-    F501502Cd,
-    S498Cd,
-)
-from lobbying import (
-    CvrRegistrationCd,
-    Cvr2RegistrationCd,
-    CvrLobbyDisclosureCd,
-    Cvr2LobbyDisclosureCd,
-    LobbyAmendmentsCd,
-    F690P2Cd,
-    LattCd,
-    LexpCd,
-    LccmCd,
-    LothCd,
-    LempCd,
-    LpayCd,
-)
-from common import (
-    FilernameCd,
-    FilerFilingsCd,
-    FilingsCd,
-    SmryCd,
-    CvrE530Cd,
-    TextMemoCd,
-)
-from other import (
-    AcronymsCd,
-    AddressCd,
-    BallotMeasuresCd,
-    EfsFilingLogCd,
-    FilersCd,
-    FilerAcronymsCd,
-    FilerAddressCd,
-    FilerEthicsClassCd,
-    FilerInterestsCd,
-    FilerLinksCd,
-    FilerStatusTypesCd,
-    FilerToFilerTypeCd,
-    FilerTypesCd,
-    FilerXrefCd,
-    FilingPeriodCd,
-    GroupTypesCd,
-    HeaderCd,
-    HdrCd,
-    ImageLinksCd,
-    LegislativeSessionsCd,
-    LobbyingChgLogCd,
-    LobbyistContributions1Cd,
-    LobbyistContributions2Cd,
-    LobbyistContributions3Cd,
-    LobbyistEmployer1Cd,
-    LobbyistEmployer2Cd,
-    LobbyistEmployer3Cd,
-    LobbyistEmployerFirms1Cd,
-    LobbyistEmployerFirms2Cd,
-    LobbyistEmpLobbyist1Cd,
-    LobbyistEmpLobbyist2Cd,
-    LobbyistFirm1Cd,
-    LobbyistFirm2Cd,
-    LobbyistFirm3Cd,
-    LobbyistFirmEmployer1Cd,
-    LobbyistFirmEmployer2Cd,
-    LobbyistFirmLobbyist1Cd,
-    LobbyistFirmLobbyist2Cd,
-    LookupCode,
-    NamesCd,
-    ReceivedFilingsCd,
-    ReportsCd,
+    'RawDataVersion',
+    'RawDataFile'
 )
